@@ -4,18 +4,9 @@
 //@ BUG29265869 - Create cluster with custom GR settings.  {VER(>=8.0.16)}
 ||
 
-//@ BUG29265869 - Create cluster with custom GR settings for 5.7. {VER(<8.0.0)}
-||
-
 //@ BUG29265869 - Add instance with custom GR settings. {VER(>=8.0.16)}
 ||
 
-//@ BUG29265869 - Add instance with custom GR settings for 5.7. {VER(<8.0.0)}
-||
-
-//@ BUG29265869 - Persist GR settings for 5.7. {VER(<8.0.0)}
-||
-
 //@<OUT> BUG29265869 - Show initial cluster options. {VER(>=8.3.0)}
 {
     "clusterName": "test",
@@ -96,7 +87,7 @@
                 },
                 {
                     "option": "ipAllowlist",
-                    "value": "<<<ip_white_list80>>>",
+                    "value": "<<<ip_allow_list80>>>",
                     "variable": "group_replication_ip_allowlist"
                 },
                 {
@@ -113,10 +104,12 @@
                     "option": "certSubject",
                     "value": ""
                 },
+?{VER(<8.4.0)}
                 {
                     "value": "WRITESET",
                     "variable": "binlog_transaction_dependency_tracking"
                 },
+?{}
                 {
                     "value": "4",
                     "variable": "<<<__replica_keyword>>>_parallel_workers"
@@ -154,7 +147,7 @@
                 },
                 {
                     "option": "ipAllowlist",
-                    "value": "<<<ip_white_list80>>>",
+                    "value": "<<<ip_allow_list80>>>",
                     "variable": "group_replication_ip_allowlist"
                 },
                 {
@@ -171,10 +164,12 @@
                     "option": "certSubject",
                     "value": ""
                 },
+?{VER(<8.4.0)}
                 {
                     "value": "WRITESET",
                     "variable": "binlog_transaction_dependency_tracking"
                 },
+?{}
                 {
                     "value": "4",
                     "variable": "<<<__replica_keyword>>>_parallel_workers"
@@ -273,23 +268,27 @@
                 {
                     "option": "ipAllowlist",
 ?{VER(>=8.0.23)}
-                    "value": "<<<ip_white_list80>>>",
+                    "value": "<<<ip_allow_list80>>>",
 ?{}
 ?{VER(<8.0.23)}
                     "value": null,
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
+?{VER(<8.0.23)}
                 {
                     "option": "ipWhitelist",
-?{VER(>=8.0.23)}
-                    "value": "AUTOMATIC",
-?{}
-?{VER(<8.0.23)}
-                    "value": "<<<ip_white_list80>>>",
-?{}
+                    "value": "<<<ip_allow_list80>>>",
                     "variable": "group_replication_ip_whitelist"
                 },
+?{}
+?{(VER(>=8.0.23) && VER(<8.0.37)) || VER(>=8.1.0)}
+                {
+                    "option": "ipWhitelist",
+                    "value": "AUTOMATIC",
+                    "variable": "group_replication_ip_whitelist"
+                },
+?{}
                 {
                     "option": "localAddress",
                     "value": "<<<local_address1>>>",
@@ -374,23 +373,27 @@
                 {
                     "option": "ipAllowlist",
 ?{VER(>=8.0.23)}
-                    "value": "<<<ip_white_list80>>>",
+                    "value": "<<<ip_allow_list80>>>",
 ?{}
 ?{VER(<8.0.23)}
                     "value": null,
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
+?{VER(<8.0.23)}
                 {
                     "option": "ipWhitelist",
-?{VER(>=8.0.23)}
-                    "value": "AUTOMATIC",
-?{}
-?{VER(<8.0.23)}
-                    "value": "<<<ip_white_list80>>>",
-?{}
+                    "value": "<<<ip_allow_list80>>>",
                     "variable": "group_replication_ip_whitelist"
                 },
+?{}
+?{(VER(>=8.0.23) && VER(<8.0.37)) || VER(>=8.1.0)}
+                {
+                    "option": "ipWhitelist",
+                    "value": "AUTOMATIC",
+                    "variable": "group_replication_ip_whitelist"
+                },
+?{}
                 {
                     "option": "localAddress",
                     "value": "<<<local_address2>>>",
@@ -450,195 +453,6 @@
     }
 }
 
-//@<OUT> BUG29265869 - Show initial cluster options. {VER(<8.0.0)}
-{
-    "clusterName": "test",
-    "defaultReplicaSet": {
-        "globalOptions": [
-            {
-                "option": "groupName",
-                "value": "<<<grp_name>>>",
-                "variable": "group_replication_group_name"
-            },
-            {
-                "option": "memberSslMode",
-                "value": "REQUIRED",
-                "variable": "group_replication_ssl_mode"
-            },
-            {
-                "option": "transactionSizeLimit",
-                "value": "[[*]]",
-                "variable": "group_replication_transaction_size_limit"
-            },
-            {
-                "option": "disableClone",
-                "value": true
-            },
-            {
-                "option": "replicationAllowedHost", 
-                "value": "%"
-            },
-            {
-                "option": "memberAuthType",
-                "value": "PASSWORD"
-            },
-            {
-                "option": "certIssuer",
-                "value": ""
-            }
-        ],
-        "tags": {
-            ".global": [],
-            "<<<uri1>>>": [],
-            "<<<uri2>>>": []
-        },
-        "topology": {
-            "<<<uri1>>>": [
-                {
-                    "option": "autoRejoinTries",
-                    "value": null,
-                    "variable": "group_replication_autorejoin_tries"
-                },
-                {
-                    "option": "consistency",
-                    "value": null,
-                    "variable": "group_replication_consistency"
-                },
-                {
-                    "option": "exitStateAction",
-                    "value": "READ_ONLY",
-                    "variable": "group_replication_exit_state_action"
-                },
-                {
-                    "option": "expelTimeout",
-                    "value": null,
-                    "variable": "group_replication_member_expel_timeout"
-                },
-                {
-                    "option": "groupSeeds",
-                    "value": "<<<local_address2>>>",
-                    "variable": "group_replication_group_seeds"
-                },
-                {
-                    "option": "ipAllowlist",
-                    "value": null,
-                    "variable": "group_replication_ip_allowlist"
-                },
-                {
-                    "option": "ipWhitelist",
-                    "value": "<<<ip_white_list57>>>",
-                    "variable": "group_replication_ip_whitelist"
-                },
-                {
-                    "option": "localAddress",
-                    "value": "<<<local_address1>>>",
-                    "variable": "group_replication_local_address"
-                },
-                {
-                    "option": "memberWeight",
-                    "value": "50",
-                    "variable": "group_replication_member_weight"
-                },
-                {
-                    "option": "certSubject",
-                    "value": ""
-                },
-                {
-                    "value": "COMMIT_ORDER",
-                    "variable": "binlog_transaction_dependency_tracking"
-                },
-                {
-                    "value": "DATABASE",
-                    "variable": "<<<__replica_keyword>>>_parallel_type"
-                },
-                {
-                    "value": "0",
-                    "variable": "<<<__replica_keyword>>>_parallel_workers"
-                },
-                {
-                    "value": "OFF",
-                    "variable": "<<<__replica_keyword>>>_preserve_commit_order"
-                },
-                {
-                    "value": "XXHASH64",
-                    "variable": "transaction_write_set_extraction"
-                }
-            ],
-            "<<<uri2>>>": [
-                {
-                    "option": "autoRejoinTries",
-                    "value": null,
-                    "variable": "group_replication_autorejoin_tries"
-                },
-                {
-                    "option": "consistency",
-                    "value": null,
-                    "variable": "group_replication_consistency"
-                },
-                {
-                    "option": "exitStateAction",
-                    "value": "READ_ONLY",
-                    "variable": "group_replication_exit_state_action"
-                },
-                {
-                    "option": "expelTimeout",
-                    "value": null,
-                    "variable": "group_replication_member_expel_timeout"
-                },
-                {
-                    "option": "groupSeeds",
-                    "value": "<<<local_address1>>>",
-                    "variable": "group_replication_group_seeds"
-                },
-                {
-                    "option": "ipAllowlist",
-                    "value": null,
-                    "variable": "group_replication_ip_allowlist"
-                },
-                {
-                    "option": "ipWhitelist",
-                    "value": "<<<ip_white_list57>>>",
-                    "variable": "group_replication_ip_whitelist"
-                },
-                {
-                    "option": "localAddress",
-                    "value": "<<<local_address2>>>",
-                    "variable": "group_replication_local_address"
-                },
-                {
-                    "option": "memberWeight",
-                    "value": "75",
-                    "variable": "group_replication_member_weight"
-                },
-                {
-                    "option": "certSubject",
-                    "value": ""
-                },
-                {
-                    "value": "COMMIT_ORDER",
-                    "variable": "binlog_transaction_dependency_tracking"
-                },
-                {
-                    "value": "DATABASE",
-                    "variable": "<<<__replica_keyword>>>_parallel_type"
-                },
-                {
-                    "value": "0",
-                    "variable": "<<<__replica_keyword>>>_parallel_workers"
-                },
-                {
-                    "value": "OFF",
-                    "variable": "<<<__replica_keyword>>>_preserve_commit_order"
-                },
-                {
-                    "value": "XXHASH64",
-                    "variable": "transaction_write_set_extraction"
-                }
-            ]
-        }
-    }
-}
-
 //@ BUG29265869 - Kill all cluster members.
 ||
 
@@ -728,7 +542,7 @@
                 },
                 {
                     "option": "ipAllowlist",
-                    "value": "<<<ip_white_list80>>>",
+                    "value": "<<<ip_allow_list80>>>",
                     "variable": "group_replication_ip_allowlist"
                 },
                 {
@@ -745,10 +559,12 @@
                     "option": "certSubject",
                     "value": ""
                 },
+?{VER(<8.4.0)}
                 {
                     "value": "WRITESET",
                     "variable": "binlog_transaction_dependency_tracking"
                 },
+?{}
                 {
                     "value": "4",
                     "variable": "<<<__replica_keyword>>>_parallel_workers"
@@ -786,7 +602,7 @@
                 },
                 {
                     "option": "ipAllowlist",
-                    "value": "<<<ip_white_list80>>>",
+                    "value": "<<<ip_allow_list80>>>",
                     "variable": "group_replication_ip_allowlist"
                 },
                 {
@@ -803,10 +619,12 @@
                     "option": "certSubject",
                     "value": ""
                 },
+?{VER(<8.4.0)}
                 {
                     "value": "WRITESET",
                     "variable": "binlog_transaction_dependency_tracking"
                 },
+?{}
                 {
                     "value": "4",
                     "variable": "<<<__replica_keyword>>>_parallel_workers"
@@ -905,24 +723,24 @@
                 {
                     "option": "ipAllowlist",
 ?{VER(>=8.0.23)}
-                    "value": "<<<ip_white_list80>>>",
+                    "value": "<<<ip_allow_list80>>>",
 ?{}
 ?{VER(<8.0.23)}
                     "value": null,
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
-?{VER(<8.3.0)}
+?{VER(<8.0.23)}
                 {
                     "option": "ipWhitelist",
+                    "value": "<<<ip_allow_list80>>>",
+                    "variable": "group_replication_ip_whitelist"
+                },
 ?{}
-?{VER(>=8.0.23) && VER(<8.3.0)}
+?{(VER(>=8.0.23) && VER(<8.0.37)) || VER(>=8.1.0)}
+                {
+                    "option": "ipWhitelist",
                     "value": "AUTOMATIC",
-?{}
-?{VER(<8.0.23)}
-                    "value": "<<<ip_white_list80>>>",
-?{}
-?{VER(<8.3.0)}
                     "variable": "group_replication_ip_whitelist"
                 },
 ?{}
@@ -1012,24 +830,24 @@
                 {
                     "option": "ipAllowlist",
 ?{VER(>=8.0.23)}
-                    "value": "<<<ip_white_list80>>>",
+                    "value": "<<<ip_allow_list80>>>",
 ?{}
 ?{VER(<8.0.23)}
                     "value": null,
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
-?{VER(<8.3.0)}
+?{VER(<8.0.23)}
                 {
                     "option": "ipWhitelist",
+                    "value": "<<<ip_allow_list80>>>",
+                    "variable": "group_replication_ip_whitelist"
+                },
 ?{}
-?{VER(>=8.0.23) && VER(<8.3.0)}
+?{(VER(>=8.0.23) && VER(<8.0.37)) || VER(>=8.1.0)}
+                {
+                    "option": "ipWhitelist",
                     "value": "AUTOMATIC",
-?{}
-?{VER(<8.0.23)}
-                    "value": "<<<ip_white_list80>>>",
-?{}
-?{VER(<8.3.0)}
                     "variable": "group_replication_ip_whitelist"
                 },
 ?{}
@@ -1094,239 +912,6 @@
     }
 }
 
-//@<OUT> BUG29265869 - Show cluster options after reboot.  {VER(<8.0.0)}
-{
-    "clusterName": "test",
-    "defaultReplicaSet": {
-        "globalOptions": [
-            {
-                "option": "groupName",
-                "value": "<<<grp_name>>>",
-                "variable": "group_replication_group_name"
-            },
-            {
-                "option": "memberSslMode",
-                "value": "REQUIRED",
-                "variable": "group_replication_ssl_mode"
-            },
-            {
-                "option": "transactionSizeLimit",
-                "value": "[[*]]",
-                "variable": "group_replication_transaction_size_limit"
-            },
-            {
-                "option": "disableClone",
-                "value": true
-            },
-            {
-                "option": "replicationAllowedHost",
-                "value": "%"
-            },
-            {
-                "option": "memberAuthType",
-                "value": "PASSWORD"
-            },
-            {
-                "option": "certIssuer",
-                "value": ""
-            }
-        ],
-        "tags": {
-            ".global": [],
-            "<<<uri1>>>": [],
-            "<<<uri2>>>": []
-        },
-        "topology": {
-            "<<<uri1>>>": [
-                {
-                    "option": "autoRejoinTries",
-                    "value": null,
-                    "variable": "group_replication_autorejoin_tries"
-                },
-                {
-                    "option": "consistency",
-                    "value": null,
-                    "variable": "group_replication_consistency"
-                },
-                {
-                    "option": "exitStateAction",
-                    "value": "READ_ONLY",
-                    "variable": "group_replication_exit_state_action"
-                },
-                {
-                    "option": "expelTimeout",
-                    "value": null,
-                    "variable": "group_replication_member_expel_timeout"
-                },
-                {
-                    "option": "groupSeeds",
-                    "value": "<<<local_address2>>>",
-                    "variable": "group_replication_group_seeds"
-                },
-                {
-                    "option": "ipAllowlist",
-                    "value": null,
-                    "variable": "group_replication_ip_allowlist"
-                },
-                {
-                    "option": "ipWhitelist",
-                    "value": "<<<ip_white_list57>>>",
-                    "variable": "group_replication_ip_whitelist"
-                },
-                {
-                    "option": "localAddress",
-                    "value": "<<<local_address1>>>",
-                    "variable": "group_replication_local_address"
-                },
-                {
-                    "option": "memberWeight",
-                    "value": "50",
-                    "variable": "group_replication_member_weight"
-                },
-                {
-                    "option": "certSubject",
-                    "value": ""
-                },
-                {
-?{VER(>=8.0.23)}
-                    "value": "WRITESET",
-?{}
-?{VER(<8.0.23)}
-                    "value": "COMMIT_ORDER",
-?{}
-                    "variable": "binlog_transaction_dependency_tracking"
-                },
-                {
-?{VER(>=8.0.23)}
-                    "value": "LOGICAL_CLOCK",
-?{}
-?{VER(<8.0.23)}
-                    "value": "DATABASE",
-?{}
-                    "variable": "<<<__replica_keyword>>>_parallel_type"
-                },
-                {
-?{VER(>=8.0.23)}
-                    "value": "4",
-?{}
-?{VER(<8.0.23)}
-                    "value": "0",
-?{}
-                    "variable": "<<<__replica_keyword>>>_parallel_workers"
-                },
-                {
-?{VER(>=8.0.23)}
-                    "value": "ON",
-?{}
-?{VER(<8.0.23)}
-                    "value": "OFF",
-?{}
-                    "variable": "<<<__replica_keyword>>>_preserve_commit_order"
-?{VER(<8.3.0)}
-                },
-                {
-                    "value": "XXHASH64",
-                    "variable": "transaction_write_set_extraction"
-?{}
-                }
-            ],
-            "<<<uri2>>>": [
-                {
-                    "option": "autoRejoinTries",
-                    "value": null,
-                    "variable": "group_replication_autorejoin_tries"
-                },
-                {
-                    "option": "consistency",
-                    "value": null,
-                    "variable": "group_replication_consistency"
-                },
-                {
-                    "option": "exitStateAction",
-                    "value": "READ_ONLY",
-                    "variable": "group_replication_exit_state_action"
-                },
-                {
-                    "option": "expelTimeout",
-                    "value": null,
-                    "variable": "group_replication_member_expel_timeout"
-                },
-                {
-                    "option": "groupSeeds",
-                    "value": "<<<local_address1>>>",
-                    "variable": "group_replication_group_seeds"
-                },
-                {
-                    "option": "ipAllowlist",
-                    "value": null,
-                    "variable": "group_replication_ip_allowlist"
-                },
-                {
-                    "option": "ipWhitelist",
-                    "value": "<<<ip_white_list57>>>",
-                    "variable": "group_replication_ip_whitelist"
-                },
-                {
-                    "option": "localAddress",
-                    "value": "<<<local_address2>>>",
-                    "variable": "group_replication_local_address"
-                },
-                {
-                    "option": "memberWeight",
-                    "value": "75",
-                    "variable": "group_replication_member_weight"
-                },
-                {
-                    "option": "certSubject",
-                    "value": ""
-                },
-                {
-?{VER(>=8.0.23)}
-                    "value": "WRITESET",
-?{}
-?{VER(<8.0.23)}
-                    "value": "COMMIT_ORDER",
-?{}
-                    "variable": "binlog_transaction_dependency_tracking"
-                },
-                {
-?{VER(>=8.0.23)}
-                    "value": "LOGICAL_CLOCK",
-?{}
-?{VER(<8.0.23)}
-                    "value": "DATABASE",
-?{}
-                    "variable": "<<<__replica_keyword>>>_parallel_type"
-                },
-                {
-?{VER(>=8.0.23)}
-                    "value": "4",
-?{}
-?{VER(<8.0.23)}
-                    "value": "0",
-?{}
-                    "variable": "<<<__replica_keyword>>>_parallel_workers"
-                },
-                {
-?{VER(>=8.0.23)}
-                    "value": "ON",
-?{}
-?{VER(<8.0.23)}
-                    "value": "OFF",
-?{}
-                    "variable": "<<<__replica_keyword>>>_preserve_commit_order"
-?{VER(<8.3.0)}
-                },
-                {
-                    "value": "XXHASH64",
-                    "variable": "transaction_write_set_extraction"
-?{}
-                }
-            ]
-        }
-    }
-}
-
 //@<OUT> BUG#29305551: Reboot cluster from complete outage must fail if async replication is configured on the target instance
 ERROR: Cannot bootstrap cluster on instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' because it has asynchronous (source-replica) replication channel(s) configured. MySQL InnoDB Cluster does not support manually configured channels as they are not managed using the AdminAPI (e.g. when PRIMARY moves to another member) which may cause cause replication to break or even create split-brain scenarios (data loss).
 
